/*
 * Copyright (c) 2019 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#include "shared/log.h"

#include <assert.h>
#include <gio/gio.h>
#include <stdbool.h>

bool bus_get(GDBusConnection **connection)
{
	assert(connection);

	GError *error = NULL;
	GDBusConnection *conn = g_bus_get_sync(G_BUS_TYPE_SYSTEM, NULL, &error);
	if (error) {
		_E("Failed to get D-Bus system bus: %s", error->message);
		g_error_free(error);
		return false;
	}

	*connection = conn;
	return true;
}

void bus_put(GDBusConnection *connection)
{
	assert(connection);

	g_object_unref(connection);
}

